@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http2
 version: 1.6.0
-id: http2-1.6.0-5a3c10b32b40700aa78aff4a30dc8790
-key: http2_LhvHuTBAvJmH3RlqrZ0NdL
+id: http2-1.6.0-d2e1144627a6b24ef6e2d1bd89ea06c3
+key: http2_1pzL1VNA2PW17UvFMfezwN
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: HTTP/2.0 library including frames and HPACK
@@ -31,14 +31,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.6.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.6.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/http2-1.6.0
-hs-libraries: HShttp2-1.6.0-LhvHuTBAvJmH3RlqrZ0NdL
+hs-libraries: HShttp2-1.6.0-1pzL1VNA2PW17UvFMfezwN
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    psqueues-0.2.2.0-1c442d35f7d41befefb8cfb402624ddd
+    psqueues-0.2.2.1-7824de609dc312a467c2b75622b6db3f
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
 haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
 haddock-html: /usr/share/doc/haskell-http2/html
